@@ -2,7 +2,7 @@
  *  GSPdf.m: Principal Class  
  *  of the GNUstep GSPdf application
  *
- *  Copyright (c) 2002-2009 GNUstep Application Project
+ *  Copyright (c) 2002-2010 GNUstep Application Project
  *  
  *  Author: Riccardo Mottola
  *  Copyright (c) 2002 Enrico Sersale <enrico@imago.ro>
@@ -62,9 +62,13 @@ static GSPdf *gspdf = nil;
   return gspdf;
 }
 
+- (BOOL)applicationShouldOpenUntitledFile:(NSApplication *)theApplication
+{
+    return NO;
+}
+
 - (void)dealloc
 {
-  RELEASE (documents);
   RELEASE (workPath);
   RELEASE (paperSizes);
   RELEASE (gsConsole);
@@ -93,7 +97,7 @@ static GSPdf *gspdf = nil;
   return self;
 }
 
-- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
+- (void)applicationWillFinishLaunching:(NSNotification *)aNotification
 {
   NSUserDefaults *defaults;
   NSString *gsPathStr;
@@ -132,13 +136,24 @@ static GSPdf *gspdf = nil;
     gsPathStr = @"/usr/bin/gs";
 #endif
     }
-
+  [gsPath release];
   gsPath = [[NSString stringWithString:gsPathStr] retain];
 }
 
 - (BOOL)application:(NSApplication *)app openFile:(NSString *)filename
 {
-  return [self openDocumentForPath: filename];
+  NSDocumentController *dc;
+  GSPdfDocument *doc;
+
+  dc = [NSDocumentController sharedDocumentController];
+  doc = [dc openDocumentWithContentsOfFile:filename display:YES];
+
+  if (doc)
+    {
+      ASSIGN (workPath, [filename stringByDeletingLastPathComponent]);
+      return YES;
+    }	
+  return NO;
 }
 
 - (BOOL)applicationShouldTerminate:(NSApplication *)app 
@@ -148,11 +163,11 @@ static GSPdf *gspdf = nil;
   for (i = 0; i < [documents count]; i++)
     {
       GSPdfDocument *doc = [documents objectAtIndex: i];
-      BOOL isPdf = [doc isPdf];
 				
-      [doc clearTempFiles];
+      [doc clearTempFiles]; 
 		
-      if (isPdf) {
+      if ([doc isPdf])
+      { // TODO shouldn't the document handle this by itselsf?
 	[[NSFileManager defaultManager] removeFileAtPath: [doc myPath] 
 					handler: nil];		
       }
@@ -161,42 +176,6 @@ static GSPdf *gspdf = nil;
   return YES;
 }
 
-- (BOOL)openDocumentForPath:(NSString *)path
-{
-  GSPdfDocument *doc = [[GSPdfDocument alloc] initForPath: path];
-
-  if (doc)
-    {
-      [documents addObject: doc];
-      RELEASE (doc);
-      ASSIGN (workPath, [path stringByDeletingLastPathComponent]);
-      return YES;
-    }	
-  return NO;
-}
-
-- (void)openFile:(id)sender
-{
-  NSOpenPanel *openPanel;
-  int result;
-
-  openPanel = [NSOpenPanel openPanel];
-  [openPanel setTitle: @"open"];	
-  [openPanel setAllowsMultipleSelection: NO];
-  [openPanel setCanChooseFiles: YES];
-  [openPanel setCanChooseDirectories: NO];
-
-  result = [openPanel runModalForDirectory: workPath file: nil 
-		      types: [NSArray arrayWithObjects: @"ps", @"PS", @"eps", @"EPS", @"pdf", @"PDF", nil]];
-
-  if(result != NSOKButton)
-    {
-      return;
-    }
-	
-  [self openDocumentForPath: [openPanel filename]];
-}
-
 - (void)documentHasClosed:(GSPdfDocument *)doc
 {
   [doc clearTempFiles];
@@ -253,7 +232,8 @@ static GSPdf *gspdf = nil;
   if (gsPathStr != nil)
     {
       [defaults setObject:gsPathStr forKey:GHOSTSCRIPT_PATH_KEY];
-      gsPath = gsPathStr;
+      [gsPath release];
+      gsPath = [[NSString stringWithString:gsPathStr] retain];
     }
 
   [prefPanel performClose:nil];
@@ -283,7 +263,16 @@ static GSPdf *gspdf = nil;
       return;
     }
   [gsPathField setStringValue:[openPanel filename]];
-  NSLog(@"path %@", [openPanel filename]);
+}
+
+- (IBAction)previousPage:(id)sender
+{
+  [[[NSDocumentController sharedDocumentController] currentDocument] previousPage];
+}
+
+- (IBAction)nextPage:(id)sender
+{
+  [[[NSDocumentController sharedDocumentController] currentDocument] nextPage];
 }
 
 - (void)runInfoPanel:(id)sender
