@@ -2,7 +2,7 @@
  *  GSPdfDocument.m: Implementation of the GSPdfDocument Class 
  *  of the GSPdf application
  *
- *  Copyright (c) 2002-2009 GNUstep Application Project
+ *  Copyright (c) 2002-2010 GNUstep Application Project
  *  
  *  Author: Enrico Sersale
  *  Date: February 2002
@@ -29,198 +29,155 @@
 #import "GSPdfDocWin.h"
 #import "PSDocument.h"
 #import "GSPdf.h"
-#import "GSPdfImView.h"
 #import "GSConsole.h"
 #import "GNUstep.h"
 
+
 @implementation GSPdfDocument
 
 - (void)dealloc
-{	
+{
+  [self clearTempFiles];
+  if (isPdf)
+    {
+      [fm removeFileAtPath: myPath handler: nil];
+    }
   [[NSNotificationCenter defaultCenter] removeObserver: self];
   if (task && [task isRunning])
     {
       [task terminate];
     } 
-  TEST_RELEASE (task);
+  RELEASE (task);
   RELEASE (myPath);
-  RELEASE (myName);
-  TEST_RELEASE (psdoc);
-  RELEASE (imageView);
+  RELEASE (psdoc);
   RELEASE (pagesMatrix);
   [gsComm release];
 
   [super dealloc];
 }
 
-- (id)initForPath:(NSString *)apath
+- (BOOL)readFromFile:(NSString *)fileName ofType:(NSString *)docType
 {
-  self = [super init];
+  gspdf = [GSPdf gspdf];
+  console = [gspdf console];
+  nc = [NSNotificationCenter defaultCenter];
+  fm = [NSFileManager defaultManager];		
+  ASSIGN (myPath, fileName);
+  isPdf = [docType isEqual: @"PDF"];	
+  gsComm = [[gspdf gsPath] retain];
+  pageindex = 0;
+  resolution = 72;
+  pagew = 595;
+  pageh = 842;
 
-  if (self) 
-    {	
-      NSArray *docPages;
-      NSString *ext;
-      NSImage *miniPage;
-      id cell;
-      int i, count;
+  if (isPdf)
+    {
+      NSDictionary *pageIdent = [gspdf uniquePageIdentifier];
+      NSString *dscPath = [pageIdent objectForKey: @"dscpath"];
+      NSMutableArray *args = [NSMutableArray arrayWithCapacity: 1];		
 
-#define RETURNERR {						\
-	NSString *msg = NSLocalizedString(@"Can't load ", @""); \
-	NSRunAlertPanel(@"error",				\
-			[msg stringByAppendingString: myName],	\
-			@"Continue", nil, nil);			\
-	return self;						\
-      }
+      [args addObject: @"-q"];
+      [args addObject: @"-dNODISPLAY"];
+      [args addObject: @"-dSAFER"];
+      [args addObject: @"-dDELAYSAFER"];
+      [args addObject: [NSString stringWithFormat: @"-sPDFname=%@", myPath]];
+      [args addObject: [NSString stringWithFormat: @"-sDSCname=%@", dscPath]];
+      [args addObject: @"pdf2dsc.ps"];
+      [args addObject: @"-c"];
+      [args addObject: @"quit"];
 
-      gspdf = [GSPdf gspdf];
-      console = [gspdf console];
-      nc = [NSNotificationCenter defaultCenter];
-      fm = [NSFileManager defaultManager];		
-      ASSIGN (myPath, apath);
-      ext = [myPath pathExtension];
-      isPdf = (([ext isEqual: @"pdf"]) || ([ext isEqual: @"PDF"]));
-      ASSIGN (myName, [myPath lastPathComponent]);		
-      gsComm = [[gspdf gsPath] retain];
-      pageindex = 0;
-      resolution = 72;
-      pagew = 595;
-      pageh = 842;
-      [self setBusy: NO];
+      ASSIGN (task, [NSTask new]);
+      [task setLaunchPath: gsComm];
+      [task setArguments: args];		
+      [task launch];
+      [task waitUntilExit];
 
-      docwin = [GSPdfDocWin new];
-      window = [docwin window];
-      [window setTitle: myName];
-      [window setDelegate: self];
-
-      imageView = [[GSPdfImView alloc] initForDocument: self];
-      [imageView setImageAlignment: NSImageAlignBottomLeft];
-      [imageView setImageScaling: NSScaleNone];
-
-      scroll = [docwin scroll];
-      [scroll setDocumentView: imageView];
-
-      leftButt = [docwin leftButt];
-      [leftButt setTarget: self];
-      [leftButt setAction: @selector(previousPage:)];
-
-      rightButt = [docwin rightButt];
-      [rightButt setTarget: self];
-      [rightButt setAction: @selector(nextPage:)];
-
-      matrixScroll = [docwin matrixScroll];
-
-      cell = AUTORELEASE ([NSButtonCell new]);
-      [cell setButtonType: NSPushOnPushOffButton];
-      [cell setImagePosition: NSImageOverlaps]; 
-
-      pagesMatrix = [[NSMatrix alloc] initWithFrame: NSZeroRect
-				      mode: NSRadioModeMatrix prototype: cell
-				      numberOfRows: 0 numberOfColumns: 0];
-      [pagesMatrix setIntercellSpacing: NSZeroSize];
-      [pagesMatrix setCellSize: NSMakeSize(26, 24)];
-      [pagesMatrix setAllowsEmptySelection: YES];
-      [pagesMatrix setTarget: self];
-      [pagesMatrix setAction: @selector(goToPage:)];
-      [matrixScroll setDocumentView: pagesMatrix];	
-
-      zoomField = [docwin zoomField];
-      [zoomField setSelectable: NO];
-      [zoomField setEditable: NO];
-
-      zoomStepper = [docwin zoomStepper];
-      [zoomStepper setTarget: self];
-      [zoomStepper setAction: @selector(setZoomValue:)];
-      [zoomField setStringValue: [NSString stringWithFormat: @"%i", [zoomStepper intValue]]]; 
-
-      zoomButt = [docwin zoomButt];
-
-      handButt = [docwin handButt];
-
-      if (isPdf)
-	{
-	  NSDictionary *pageIdent = [gspdf uniquePageIdentifier];
-	  NSString *dscPath = [pageIdent objectForKey: @"dscpath"];
-	  NSMutableArray *args = [NSMutableArray arrayWithCapacity: 1];		
-
-	  [args addObject: @"-q"];
-	  [args addObject: @"-dNODISPLAY"];
-	  [args addObject: @"-dSAFER"];
-	  [args addObject: @"-dDELAYSAFER"];
-	  [args addObject: [NSString stringWithFormat: @"-sPDFname=%@", myPath]];
-	  [args addObject: [NSString stringWithFormat: @"-sDSCname=%@", dscPath]];
-	  [args addObject: @"pdf2dsc.ps"];
-	  [args addObject: @"-c"];
-	  [args addObject: @"quit"];
-
-
-	  ASSIGN (task, [NSTask new]);
-	  [task setLaunchPath: gsComm];
-	  [task setArguments: args];		
-	  [task launch];
-	  [task waitUntilExit];
-
-	  if ([task terminationStatus] == 0)
-	    {
-	      ASSIGN (myPath, dscPath);
-	      psdoc = [[PSDocument alloc] initWithPsFileAtPath: myPath];
-	      if (psdoc == nil) 
-		{
-		  RETURNERR;
-		}
-	    } else
-	    {
-	      RETURNERR;
-	    }					 
-
-	} else
+      if ([task terminationStatus] == 0)
 	{
+	  ASSIGN (myPath, dscPath);
 	  psdoc = [[PSDocument alloc] initWithPsFileAtPath: myPath];
-	  if (psdoc == nil) {
-	    RETURNERR;
-	  }
+	  if (psdoc == nil)
+	    {
+	      NSLog(@"init with ps file failed");
+	      return NO;
+	    }
+	}					 
+
+    } else
+    {
+      psdoc = [[PSDocument alloc] initWithPsFileAtPath: myPath];
+      if (psdoc == nil)
+	{
+	  return NO;
 	}
-
-      docPages = [psdoc pages];
-      count = [docPages count];
-
-      [pagesMatrix renewRows: 1 columns: count];		
-      miniPage = [NSImage imageNamed: @"page.tiff"];
-
-      for (i = 0; i < count; i++) {
-	NSDictionary *pageIdent = [gspdf uniquePageIdentifier];
-	NSString *psPath = [pageIdent objectForKey: @"pspath"];
-	NSString *tiffPath = [pageIdent objectForKey: @"tiffpath"];
-	NSString *dscPath = [pageIdent objectForKey: @"dscpath"];		
-	PSDocumentPage *pspage = [docPages objectAtIndex: i];
-
-	[pspage setPsPath: psPath];
-	[pspage setTiffPath: tiffPath];
-	[pspage setDscPath: dscPath];
-
-	cell = [pagesMatrix cellAtRow: 0 column: i];
-	if (i < 100)
-	  {
-	    [cell setFont: [NSFont systemFontOfSize: 10]];
-	  } else {
-	  [cell setFont: [NSFont systemFontOfSize: 8]];
-	}
-	[cell setImage: miniPage];	   
-	[cell setTitle: [NSString stringWithFormat: @"%i", i+1]];	  
-      }
-      [pagesMatrix sizeToCells];
-
-      [self makePage];
     }
+ 
+  return YES;
+}
 
-  return self;
+- (void)windowControllerDidLoadNib: (NSWindowController *)winController
+{
+  NSArray *docPages;
+  NSImage *miniPage;
+  id cell;
+  int i, count;
+    
+  [super windowControllerDidLoadNib: winController];
+  
+  [self setBusy: NO];
+
+  matrixScroll = [docwin matrixScroll];
+
+  cell = AUTORELEASE ([NSButtonCell new]);
+  [cell setButtonType: NSPushOnPushOffButton];
+  [cell setImagePosition: NSImageOverlaps]; 
+
+  pagesMatrix = [[NSMatrix alloc] initWithFrame: NSZeroRect
+					   mode: NSRadioModeMatrix prototype: cell
+				   numberOfRows: 0 numberOfColumns: 0];
+  [pagesMatrix setIntercellSpacing: NSZeroSize];
+  [pagesMatrix setCellSize: NSMakeSize(26, 24)];
+  [pagesMatrix setAllowsEmptySelection: YES];
+  [pagesMatrix setTarget: self];
+  [pagesMatrix setAction: @selector(goToPage:)];
+  [matrixScroll setDocumentView: pagesMatrix];	
+
+
+  docPages = [psdoc pages];
+  count = [docPages count];
+
+  [pagesMatrix renewRows: 1 columns: count];		
+  miniPage = [NSImage imageNamed: @"page.tiff"];
+
+  for (i = 0; i < count; i++)
+    {
+      NSDictionary *pageIdent = [gspdf uniquePageIdentifier];
+      NSString *psPath = [pageIdent objectForKey: @"pspath"];
+      NSString *tiffPath = [pageIdent objectForKey: @"tiffpath"];
+      NSString *dscPath = [pageIdent objectForKey: @"dscpath"];		
+      PSDocumentPage *pspage = [docPages objectAtIndex: i];
+
+      [pspage setPsPath: psPath];
+      [pspage setTiffPath: tiffPath];
+      [pspage setDscPath: dscPath];
+
+      cell = [pagesMatrix cellAtRow: 0 column: i];
+      if (i < 100)
+	[cell setFont: [NSFont systemFontOfSize: 10]];
+      else
+	[cell setFont: [NSFont systemFontOfSize: 8]];
+      [cell setImage: miniPage];	   
+      [cell setTitle: [NSString stringWithFormat: @"%i", i+1]];	  
+    }
+  [pagesMatrix sizeToCells];
+
+  [self makePage];
 }
 
 - (void)setBusy:(BOOL)value
 {
   busy = value;
-  [leftButt setEnabled: !busy];
-  [rightButt setEnabled: !busy];
+  [docwin setBusy: value];
 }
 
 - (NSString *)myPath
@@ -228,12 +185,12 @@
   return myPath;
 }
 
--	(BOOL)isPdf
+- (BOOL)isPdf
 {
   return isPdf;
 }
 
-- (void)nextPage:(id)sender
+- (void)nextPage
 {
   pageindex++;
   if (pageindex == [[psdoc pages] count])
@@ -244,7 +201,7 @@
   [self makePage];	
 }
 
-- (void)previousPage:(id)sender
+- (void)previousPage
 {
   pageindex--;
   if (pageindex < 0)
@@ -286,8 +243,8 @@
   if ([fm fileExistsAtPath: tiffPath])
     {
       NSImage *image = [[NSImage alloc] initWithContentsOfFile: tiffPath];
-      [imageView setFrameSize: [image size]];
-      [imageView setImage: image];
+      [[docwin imageView] setFrameSize: [image size]];
+      [docwin setImage: image];
       RELEASE (image);
       [self setBusy: NO];
       return;
@@ -322,7 +279,12 @@
   [args addObject: @"-dSAFER"];
   [args addObject: @"-dDELAYSAFER"];
   [args addObject: @"-dSHORTERRORS"];
-  [args addObject: @"-dDOINTERPOLATE"];	
+  [args addObject: @"-dDOINTERPOLATE"];
+  if ([docwin antiAlias])
+    {
+      [args addObject: @"-dTextAlphaBits=4"];
+      [args addObject: @"-dGraphicsAlphaBits=4"];
+    }
   [args addObject: [NSString stringWithFormat: @"-dDEVICEXRESOLUTION=%i", (int)resolution]];	
   [args addObject: [NSString stringWithFormat: @"-dDEVICEYRESOLUTION=%i", (int)resolution]];	
   [args addObject: [NSString stringWithFormat: @"-dDEVICEWIDTHPOINTS=%i", pagew]];	
@@ -365,11 +327,14 @@
   [task launch]; 
 }
 
-- (void)setZoomValue:(id)sender
+- (void)setZoomValue:(int)value
 {
-  int value = [sender intValue];
-  resolution = ((72.00 / 100) * value);
-  [zoomField setStringValue: [NSString stringWithFormat: @"%i", value]];		
+  resolution = ((72.00 / 100) * value);		
+  [self regeneratePage];	
+}
+
+- (void)regeneratePage
+{		
   [self clearTempFiles];	
   [self makePage];
 }
@@ -431,8 +396,7 @@
 	  [image setBackgroundColor: [NSColor windowBackgroundColor]];
 
 	  frame.size = [image size];
-	  [imageView setFrame: frame];
-	  [imageView setImage: image];
+	  [docwin setImage: image];
 	  RELEASE (image);
 
 	  if (task && [task isRunning])
@@ -488,15 +452,12 @@
     }
 }
 
-- (BOOL)windowShouldClose:(id)sender
+
+- (void)makeWindowControllers
 {
-  [self clearTempFiles];
-  if (isPdf)
-    {
-      [fm removeFileAtPath: myPath handler: nil];
-    }	
-  [window saveFrameUsingName: @"gspdfdoc"];
-  return YES;
+  docwin = [[GSPdfDocWin alloc] initWithWindowNibName:@"GSPdfDocument"];
+  NSAssert (docwin, @"created doc nib nil");
+  [self addWindowController: docwin];
 }
 
 @end
